@@ -45,6 +45,7 @@ module FactoryBot
       declaration = if block_given?
         Declaration::Dynamic.new(name, @ignore, block)
       else
+        warn_static_attribute_deprecation(name, value)
         Declaration::Static.new(name, value, @ignore)
       end
 
@@ -170,5 +171,31 @@ module FactoryBot
     def initialize_with(&block)
       @definition.define_constructor(&block)
     end
+
+    private
+
+    def warn_static_attribute_deprecation(name, value)
+      attribute_caller = caller(2)
+
+      if attribute_caller[0].include?("method_missing")
+        attribute_caller = caller(3)
+      end
+
+      ActiveSupport::Deprecation.warn(<<-MSG, attribute_caller)
+Static attributes will be removed in FactoryBot 5.0. Please use dynamic
+attributes instead by wrapping the attribute value in a block:
+
+#{name} { #{value.inspect} }
+
+To automatically update from static attributes to dynamic ones,
+install rubocop-rspec and run:
+
+rubocop \\
+  --require rubocop-rspec \\
+  --only FactoryBot/AttributeDefinedStatically \\
+  --auto-correct
+
+      MSG
+    end
   end
 end
