@@ -1,7 +1,3 @@
-$LOAD_PATH << File.join(File.dirname(__FILE__), '..', 'lib')
-$LOAD_PATH << File.join(File.dirname(__FILE__))
-
-require 'rubygems'
 require 'rspec'
 require 'rspec/its'
 
@@ -29,4 +25,7 @@ RSpec.configure do |config|
   config.after do
     Timecop.return
   end
+
+  config.order = :random
+  Kernel.srand config.seed
 end
